@@ -30,7 +30,7 @@ use vegafusion_core::planning::watch::{
 };
 use vegafusion_core::proto::gen::pretransform::{PreTransformOpts, PreTransformRequest};
 use vegafusion_core::proto::gen::services::pre_transform_result;
-use vegafusion_core::proto::gen::tasks::TaskGraph;
+use vegafusion_core::proto::gen::tasks::{TaskGraph, TzConfig};
 use vegafusion_core::spec::chart::ChartSpec;
 use vegafusion_core::task_graph::graph::ScopedVariable;
 use vegafusion_core::task_graph::task_value::TaskValue;
@@ -114,7 +114,10 @@ mod test_custom_specs {
         case("custom/ridgeline", 0.001),
         case("custom/binned_scatter", 0.001),
         case("custom/seattle_temps_heatmap", 0.001),
-        case("custom/movies_agg_parameterize", 0.001)
+        case("custom/movies_agg_parameterize", 0.001),
+        case("custom/escaped_column_name1", 0.001),
+        case("custom/layered_movies", 0.001),
+        case("custom/shipping_mixed_scales", 0.001)
     )]
     fn test_image_comparison(spec_name: &str, tolerance: f64) {
         println!("spec_name: {}", spec_name);
@@ -1362,6 +1365,10 @@ async fn check_spec_sequence(
     // Initialize runtime
     let vegajs_runtime = vegajs_runtime();
     let local_tz = vegajs_runtime.nodejs_runtime.local_timezone().unwrap();
+    let tz_config = TzConfig {
+        local_tz,
+        default_input_tz: None,
+    };
 
     let spec_plan = SpecPlan::try_new(&full_spec, &Default::default()).unwrap();
 
@@ -1384,7 +1391,10 @@ async fn check_spec_sequence(
     );
 
     // Build task graph
-    let tasks = spec_plan.server_spec.to_tasks(&local_tz, None).unwrap();
+    let tasks = spec_plan
+        .server_spec
+        .to_tasks(&tz_config, &Default::default())
+        .unwrap();
     let mut task_graph = TaskGraph::new(tasks, &task_scope).unwrap();
     let task_graph_mapping = task_graph.build_mapping();
 
@@ -1407,7 +1417,7 @@ async fn check_spec_sequence(
     for var in &spec_plan.comm_plan.server_to_client {
         let node_index = task_graph_mapping.get(var).unwrap();
         let value = runtime
-            .get_node_value(Arc::new(task_graph.clone()), node_index)
+            .get_node_value(Arc::new(task_graph.clone()), node_index, Default::default())
             .await
             .expect("Failed to get node value");
 
@@ -1475,7 +1485,7 @@ async fn check_spec_sequence(
         let mut server_to_client_value_batch = HashMap::new();
         for (var, node_index) in watch_vars.iter().zip(&watch_indices) {
             let value = runtime
-                .get_node_value(Arc::new(task_graph.clone()), node_index)
+                .get_node_value(Arc::new(task_graph.clone()), node_index, Default::default())
                 .await
                 .unwrap();
 
